@@ -1,29 +1,16 @@
-# -*- coding: utf-8 -*-
-#    Copyright (C) 2011-2019 by
-#    Aric Hagberg <hagberg@lanl.gov>
-#    Dan Schult <dschult@colgate.edu>
-#    Pieter Swart <swart@lanl.gov>
-#    All rights reserved.
-#    BSD license.
-#
-# Authors: Jordi Torrents (jtorrents@milnou.net)
-#          Dan Schult (dschult@colgate.edu)
-#          Aric Hagberg (aric.hagberg@gmail.com)
 """Biconnected components and articulation points."""
-import warnings as _warnings
 from itertools import chain
-import networkx as nx
 from networkx.utils.decorators import not_implemented_for
 
 __all__ = [
-    'biconnected_components',
-    'biconnected_component_edges',
-    'is_biconnected',
-    'articulation_points',
+    "biconnected_components",
+    "biconnected_component_edges",
+    "is_biconnected",
+    "articulation_points",
 ]
 
 
-@not_implemented_for('directed')
+@not_implemented_for("directed")
 def is_biconnected(G):
     """Returns True if the graph is biconnected, False otherwise.
 
@@ -45,7 +32,7 @@ def is_biconnected(G):
 
     Raises
     ------
-    NetworkXNotImplemented :
+    NetworkXNotImplemented
         If the input graph is not undirected.
 
     Examples
@@ -91,12 +78,14 @@ def is_biconnected(G):
     if len(bcc) == 1:
         return len(bcc[0]) == len(G)
     return False  # Multiple bicomponents or No bicomponents (empty graph?)
+
+
 #    if len(bcc) == 0:  # No bicomponents (it could be an empty graph)
 #        return False
 #    return len(bcc[0]) == len(G)
 
 
-@not_implemented_for('directed')
+@not_implemented_for("directed")
 def biconnected_component_edges(G):
     """Returns a generator of lists of edges, one list for each biconnected
     component of the input graph.
@@ -121,7 +110,7 @@ def biconnected_component_edges(G):
 
     Raises
     ------
-    NetworkXNotImplemented :
+    NetworkXNotImplemented
         If the input graph is not undirected.
 
     Examples
@@ -165,11 +154,10 @@ def biconnected_component_edges(G):
            Communications of the ACM 16: 372–378. doi:10.1145/362248.362272
 
     """
-    for comp in _biconnected_dfs(G, components=True):
-        yield comp
+    yield from _biconnected_dfs(G, components=True)
 
 
-@not_implemented_for('directed')
+@not_implemented_for("directed")
 def biconnected_components(G):
     """Returns a generator of sets of nodes, one set for each biconnected
     component of the graph
@@ -195,7 +183,7 @@ def biconnected_components(G):
 
     Raises
     ------
-    NetworkXNotImplemented :
+    NetworkXNotImplemented
         If the input graph is not undirected.
 
     See Also
@@ -265,7 +253,7 @@ def biconnected_components(G):
         yield set(chain.from_iterable(comp))
 
 
-@not_implemented_for('directed')
+@not_implemented_for("directed")
 def articulation_points(G):
     """Yield the articulation points, or cut vertices, of a graph.
 
@@ -289,7 +277,7 @@ def articulation_points(G):
 
     Raises
     ------
-    NetworkXNotImplemented :
+    NetworkXNotImplemented
         If the input graph is not undirected.
 
     Examples
@@ -339,7 +327,7 @@ def articulation_points(G):
             yield articulation
 
 
-@not_implemented_for('directed')
+@not_implemented_for("directed")
 def _biconnected_dfs(G, components=True):
     # depth-first search algorithm to generate articulation points
     # and biconnected components
