@@ -1,19 +1,20 @@
-import sys
-
 from collections import defaultdict
 from os.path import splitext
 from contextlib import contextmanager
+from pathlib import Path
 
 import networkx as nx
 from decorator import decorator
-from networkx.utils import is_string_like
+from networkx.utils import create_random_state, create_py_random_state
 
 __all__ = [
-    'not_implemented_for',
-    'open_file',
-    'nodes_or_number',
-    'preserve_random_state',
-    'random_state',
+    "not_implemented_for",
+    "open_file",
+    "nodes_or_number",
+    "preserve_random_state",
+    "random_state",
+    "np_random_state",
+    "py_random_state",
 ]
 
 
@@ -52,47 +53,54 @@ def not_implemented_for(*graph_types):
        def sp_np_function(G):
            pass
     """
+
     @decorator
     def _not_implemented_for(not_implement_for_func, *args, **kwargs):
         graph = args[0]
-        terms = {'directed': graph.is_directed(),
-                 'undirected': not graph.is_directed(),
-                 'multigraph': graph.is_multigraph(),
-                 'graph': not graph.is_multigraph()}
+        terms = {
+            "directed": graph.is_directed(),
+            "undirected": not graph.is_directed(),
+            "multigraph": graph.is_multigraph(),
+            "graph": not graph.is_multigraph(),
+        }
         match = True
         try:
             for t in graph_types:
                 match = match and terms[t]
-        except KeyError:
-            raise KeyError('use one or more of ',
-                           'directed, undirected, multigraph, graph')
+        except KeyError as e:
+            raise KeyError(
+                "use one or more of " "directed, undirected, multigraph, graph"
+            ) from e
         if match:
-            msg = 'not implemented for %s type' % ' '.join(graph_types)
+            msg = f"not implemented for {' '.join(graph_types)} type"
             raise nx.NetworkXNotImplemented(msg)
         else:
             return not_implement_for_func(*args, **kwargs)
+
     return _not_implemented_for
 
 
 def _open_gz(path, mode):
     import gzip
+
     return gzip.open(path, mode=mode)
 
 
 def _open_bz2(path, mode):
     import bz2
+
     return bz2.BZ2File(path, mode=mode)
 
 
 # To handle new extensions, define a function accepting a `path` and `mode`.
 # Then add the extension to _dispatch_dict.
 _dispatch_dict = defaultdict(lambda: open)
-_dispatch_dict['.gz'] = _open_gz
-_dispatch_dict['.bz2'] = _open_bz2
-_dispatch_dict['.gzip'] = _open_gz
+_dispatch_dict[".gz"] = _open_gz
+_dispatch_dict[".bz2"] = _open_bz2
+_dispatch_dict[".gzip"] = _open_gz
 
 
-def open_file(path_arg, mode='r'):
+def open_file(path_arg, mode="r"):
     """Decorator to ensure clean opening and closing of files.
 
     Parameters
@@ -181,33 +189,37 @@ def open_file(path_arg, mode='r'):
             # or it could have been explicitly set by the user.
             try:
                 path = kwargs[path_arg]
-            except KeyError:
+            except KeyError as e:
                 # Could not find the keyword. Thus, no default was specified
                 # in the function signature and the user did not provide it.
-                msg = 'Missing required keyword argument: {0}'
-                raise nx.NetworkXError(msg.format(path_arg))
+                msg = f"Missing required keyword argument: {path_arg}"
+                raise nx.NetworkXError(msg) from e
             else:
                 is_kwarg = True
-        except IndexError:
+        except IndexError as e:
             # A "required" argument was missing. This can only happen if
             # the decorator of the function was incorrectly specified.
             # So this probably is not a user error, but a developer error.
             msg = "path_arg of open_file decorator is incorrect"
-            raise nx.NetworkXError(msg)
+            raise nx.NetworkXError(msg) from e
         else:
             is_kwarg = False
 
         # Now we have the path_arg. There are two types of input to consider:
         #   1) string representing a path that should be opened
         #   2) an already opened file object
-        if is_string_like(path):
+        if isinstance(path, str):
             ext = splitext(path)[1]
             fobj = _dispatch_dict[ext](path, mode=mode)
             close_fobj = True
-        elif hasattr(path, 'read'):
+        elif hasattr(path, "read"):
             # path is already a file-like object
             fobj = path
             close_fobj = False
+        elif isinstance(path, Path):
+            # path is a pathlib reference to a filename
+            fobj = _dispatch_dict[path.suffix](str(path), mode=mode)
+            close_fobj = True
         else:
             # could be None, in which case the algorithm will deal with it
             fobj = path
@@ -267,6 +279,7 @@ def nodes_or_number(which_args):
            # r is a number. n can be a number of a list of nodes
            pass
     """
+
     @decorator
     def _nodes_or_number(func_to_be_decorated, *args, **kw):
         # form tuple of arg positions to be converted.
@@ -284,10 +297,11 @@ def nodes_or_number(which_args):
                 nodes = tuple(n)
             else:
                 if n < 0:
-                    msg = "Negative number of nodes not valid: %i" % n
+                    msg = "Negative number of nodes not valid: {n}"
                     raise nx.NetworkXError(msg)
             new_args[i] = (n, nodes)
         return func_to_be_decorated(*new_args, **kw)
+
     return _nodes_or_number
 
 
@@ -332,6 +346,7 @@ def preserve_random_state(func):
             with save_random_state():
                 seed(1234567890)
                 return func(*args, **kwargs)
+
         wrapper.__name__ = func.__name__
         return wrapper
     except ImportError:
@@ -342,6 +357,7 @@ def random_state(random_state_index):
     """Decorator to generate a numpy.random.RandomState instance.
 
     Argument position `random_state_index` is processed by create_random_state.
+    The result is a numpy.random.RandomState instance.
 
     Parameters
     ----------
@@ -360,29 +376,96 @@ def random_state(random_state_index):
     --------
     Decorate functions like this::
 
-       @random_state(0)
+       @np_random_state(0)
        def random_float(random_state=None):
            return random_state.rand()
 
-       @random_state(1)
+       @np_random_state(1)
        def random_array(dims, random_state=1):
            return random_state.rand(*dims)
+
+    See Also
+    --------
+    py_random_state
     """
+
     @decorator
     def _random_state(func, *args, **kwargs):
         # Parse the decorator arguments.
         try:
             random_state_arg = args[random_state_index]
-        except TypeError:
-            raise nx.NetworkXError("random_state_arg must be an integer")
-        except IndexError:
-            raise nx.NetworkXError("random_state_arg is incorrect")
+        except TypeError as e:
+            raise nx.NetworkXError("random_state_index must be an integer") from e
+        except IndexError as e:
+            raise nx.NetworkXError("random_state_index is incorrect") from e
 
         # Create a numpy.random.RandomState instance
-        random_state_instance = nx.utils.create_random_state(random_state_arg)
+        random_state = create_random_state(random_state_arg)
 
         # args is a tuple, so we must convert to list before modifying it.
         new_args = list(args)
-        new_args[random_state_index] = random_state_instance
+        new_args[random_state_index] = random_state
         return func(*new_args, **kwargs)
+
+    return _random_state
+
+
+np_random_state = random_state
+
+
+def py_random_state(random_state_index):
+    """Decorator to generate a random.Random instance (or equiv).
+
+    Argument position `random_state_index` processed by create_py_random_state.
+    The result is either a random.Random instance, or numpy.random.RandomState
+    instance with additional attributes to mimic basic methods of Random.
+
+    Parameters
+    ----------
+    random_state_index : int
+        Location of the random_state argument in args that is to be used to
+        generate the numpy.random.RandomState instance. Even if the argument is
+        a named positional argument (with a default value), you must specify
+        its index as a positional argument.
+
+    Returns
+    -------
+    _random_state : function
+        Function whose random_state keyword argument is a RandomState instance.
+
+    Examples
+    --------
+    Decorate functions like this::
+
+       @py_random_state(0)
+       def random_float(random_state=None):
+           return random_state.rand()
+
+       @py_random_state(1)
+       def random_array(dims, random_state=1):
+           return random_state.rand(*dims)
+
+    See Also
+    --------
+    np_random_state
+    """
+
+    @decorator
+    def _random_state(func, *args, **kwargs):
+        # Parse the decorator arguments.
+        try:
+            random_state_arg = args[random_state_index]
+        except TypeError as e:
+            raise nx.NetworkXError("random_state_index must be an integer") from e
+        except IndexError as e:
+            raise nx.NetworkXError("random_state_index is incorrect") from e
+
+        # Create a numpy.random.RandomState instance
+        random_state = create_py_random_state(random_state_arg)
+
+        # args is a tuple, so we must convert to list before modifying it.
+        new_args = list(args)
+        new_args[random_state_index] = random_state
+        return func(*new_args, **kwargs)
+
     return _random_state
