@@ -7,18 +7,18 @@ Do not add this file to the repository.
 
 import datetime
 
-version = '2.5'
-date = 'Sun Aug 30 09:47:30 2020'
+version = '2.5.1'
+date = 'Wed Apr  7 01:01:32 2021'
 
 # Was NetworkX built from a development version? If so, remember that the major
 # and minor versions reference the "target" (rather than "current") release.
 dev = False
 
 # Format: (name, major, min, revision)
-version_info = ('networkx', '2', '5', None)
+version_info = ('networkx', '2', '5.1', None)
 
 # Format: a 'datetime.datetime' instance
-date_info = datetime.datetime(2020, 8, 30, 9, 47, 30)
+date_info = datetime.datetime(2021, 4, 7, 1, 1, 32)
 
 # Format: (vcs, vcs_tuple)
 vcs_info = (None, (None, None))
